#!/bin/bash
# Licensed Materials - Property of IBM
# 5724-I68
#
#  Copyright IBM Corp. 2000, 2007
#
# US Government Users Restricted Rights - Use, duplication, or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.

. $DB_DIR/util/set_db.sh

DB_USER=`${ECHO} ${DB_USER_NAME} | ${TR} "abcdefghijklmnopqrstuvwxyz" "ABCDEFGHIJKLMNOPQRSTUVWXYZ"`
START_TIME=`date`


if [ "$CCD_DB" = "oracle" ]; then


STATEMENT=`cat <<EOF
PROMPT 'Checking Specs'

select 'Spec Name = ' || spc_name || '; Node name = ' || nod_name
as Spec_nodes
from nod, spc
where nod_spec_id = spc_id
and nod_next_version_id = 999999999
and nod_id in 
(select nod_id from (
select nod_id id, nod_next_version_id nxt, nod_spec_id spc, nod_company_id cmp from nod
group by nod_id, nod_next_version_id, nod_spec_id, nod_company_id
having count(1) > 1));


PROMPT 'Checking Spec Node Hierarchies'
select 'Spec Name = ' || spc_name || '; Parent node name = ' || prnt.nod_name || '; Child node name = ' || child.nod_name
as Spec_parent_child_nodes
from noh, nod prnt , nod child, spc
where noh_parent_node_id = prnt.nod_id
and noh_child_node_id = child.nod_id
and noh_spec_id = spc_id
and noh_next_version_id = 999999999
and noh_spec_id in 
(select noh_spec_id from (
select noh_spec_id spc, noh_next_version_id nxt, noh_order ord, noh_company_id cmp from noh
group by noh_spec_id, noh_next_version_id, noh_order, noh_company_id
having count(1) > 1));

PROMPT 'Checking Categories'

select cfp_full_path category_path from cfp, cat
where cfp_category_id = cat_id
and cat_next_version_id = 999999999
and cat_id in 
(select cat_id from (
select cat_id id, cat_next_version_id nxt, cat_container_id cont, cat_company_id cmp from cat i
group by cat_id, cat_next_version_id, cat_container_id, cat_company_id
having count(1) > 1));


PROMPT 'Checking Category Paths'

select cfp_full_path as category_path from cfp
where cfp_next_version_id = 999999999
and cfp_full_path in 
(select cfp_full_path from (
select cfp_full_path fp, cfp_full_path_type fpt, cfp_next_version_id nxt, cfp_cat_tree_id ctr from cfp
group by cfp_full_path, cfp_full_path_type, cfp_next_version_id, cfp_cat_tree_id
having count(1) > 1));

PROMPT 'Checking Category Hierarchies'

select 'Parent category path = ' || prnt.cfp_full_path || '; Child category path = ' || child.cfp_full_path
as category_hierarchy
from cfp prnt, cfp child, chi
where chi_parent_id = prnt.cfp_category_id
and chi_child_id = child.cfp_category_id
and chi_next_version_id = 999999999
and chi_parent_id in 
(select chi_parent_id from (
select chi_company_id cmp, chi_parent_id prn, chi_child_id chd, chi_next_version_id nxt, count(1) from chi i
group by chi_company_id, chi_parent_id, chi_child_id, chi_next_version_id
having count(1) > 1));

PROMPT 'Checking Items'

select 'Catalog name = ' || ctg_name || '; Item Primary key = ' || itm_primary_key
as item_catalog_primary_key
from itm, ctg
where itm_container_id = ctg_id
and itm_next_version_id = 999999999
and itm_id in 
(select itm_id from (
select itm_id id, itm_next_version_id nxt, itm_container_id cont, itm_company_id cmp from itm
group by itm_id, itm_next_version_id, itm_container_id, itm_company_id
having count(1) > 1));

PROMPT 'Checking Item Category Mappings'

select 'Catalog name = ' || ctg_name || '; Item Primary key = ' || itm_primary_key ||
'; Category path = ' || cfp_full_path as Item_category_mapping
from icm o
inner join itm on icm_item_id = itm_id
inner join ctg on icm_catalog_id = ctg_id
left outer join cfp on icm_category_id = cfp_category_id
where icm_next_version_id = 999999999
and icm_item_id in (
select icmitem from (
select icm_item_id icmitem, icm_next_version_id nxt, icm_cat_tree_id ctr, icm_category_id cat, icm_company_id cmp from icm
group by icm_item_id, icm_next_version_id, icm_cat_tree_id, icm_category_id, icm_company_id
having count(1) > 1));

PROMPT 'Checking Collaboration Area Info'

select 'Collaboration area name = ' || coa_name || '; Workflow name = ' || wfd_name ||
'; Workflow step name = ' || spt_leaf_step_text_path || '; Item primary key = ' || itm_primary_key
as Workflow_item_info
from wfe
left outer join coa on wfe_collaboration_area_id = coa_id
left outer join spt on wfe_source_step_at_path_id = spt_id
left outer join wfd on coa_wfl_id = wfd_id
left outer join wee on wfe_id = wee_event_id
left outer join cem on wee_entry_id = cem_ca_entry_id and cem_ca_id = coa_id
left outer join itm on cem_src_entry_id = itm_id
where wfe_event_status in ('NEW','PROCESSING')
and wfe_id in 
(select wfe_id id from wfe
group by wfe_id
having count(1) > 1);

EOF`

${ECHO} "---------------------"
${ECHO} "executing constraint violation report:"
${ECHO} "---------------------"

${CCD_SQLPLUS} ${CONNECTION} <<EOF > $TOP/logs/constraint_violation_report.out
$STATEMENT
EOF


elif [ "$CCD_DB" = "db2" ]; then



${ECHO} "---------------------"
${ECHO} "executing constraint violation report:"
${ECHO} "---------------------"

${ECHO} "

select 'Checking Specs' from sysibm.sysdummy1;

select 'Spec Name = ' || spc_name || '; Node name = ' || nod_name
as Spec_nodes
from nod, spc
where nod_spec_id = spc_id
and nod_next_version_id = 999999999
and nod_id in 
(select nod_id from (
select nod_id id, nod_next_version_id nxt, nod_spec_id spc, nod_company_id cmp from nod
group by nod_id, nod_next_version_id, nod_spec_id, nod_company_id
having count(1) > 1) as t);


select  'Checking Spec Node Hierarchies' from sysibm.sysdummy1;
select 'Spec Name = ' || spc_name || '; Parent node name = ' || prnt.nod_name || '; Child node name = ' || child.nod_name
as Spec_parent_child_nodes
from noh, nod prnt , nod child, spc
where noh_parent_node_id = prnt.nod_id
and noh_child_node_id = child.nod_id
and noh_spec_id = spc_id
and noh_next_version_id = 999999999
and noh_spec_id in 
(select noh_spec_id from (
select noh_spec_id spc, noh_next_version_id nxt, noh_order ord, noh_company_id cmp from noh
group by noh_spec_id, noh_next_version_id, noh_order, noh_company_id
having count(1) > 1) as t);

select  'Checking Categories' from sysibm.sysdummy1;

select cfp_full_path category_path from cfp, cat
where cfp_category_id = cat_id
and cat_next_version_id = 999999999
and cat_id in 
(select cat_id from (
select cat_id id, cat_next_version_id nxt, cat_container_id cont, cat_company_id cmp from cat i
group by cat_id, cat_next_version_id, cat_container_id, cat_company_id
having count(1) > 1) as t);


select  'Checking Category Paths' from sysibm.sysdummy1;

select cfp_full_path as category_path from cfp
where cfp_next_version_id = 999999999
and cfp_full_path in 
(select cfp_full_path from (
select cfp_full_path fp, cfp_full_path_type fpt, cfp_next_version_id nxt, cfp_cat_tree_id ctr from cfp
group by cfp_full_path, cfp_full_path_type, cfp_next_version_id, cfp_cat_tree_id
having count(1) > 1) as t);

select  'Checking Category Hierarchy' from sysibm.sysdummy1;

select 'Parent category path = ' || prnt.cfp_full_path || '; Child category path = ' || child.cfp_full_path
as category_hierarchy
from cfp prnt, cfp child, chi
where chi_parent_id = prnt.cfp_category_id
and chi_child_id = child.cfp_category_id
and chi_next_version_id = 999999999
and chi_parent_id in 
(select chi_parent_id from (
select chi_company_id cmp, chi_parent_id prn, chi_child_id chd, chi_next_version_id nxt, count(1) from chi i
group by chi_company_id, chi_parent_id, chi_child_id, chi_next_version_id
having count(1) > 1) as t);


select  'Checking Items' from sysibm.sysdummy1;

select 'Catalog name = ' || ctg_name || '; Item Primary key = ' || itm_primary_key
as item_catalog_primary_key
from itm, ctg
where itm_container_id = ctg_id
and itm_next_version_id = 999999999
and itm_id in 
(select itm_id from (
select itm_id id, itm_next_version_id nxt, itm_container_id cont, itm_company_id cmp from itm
group by itm_id, itm_next_version_id, itm_container_id, itm_company_id
having count(1) > 1) as t);

select  'Checking Item Category Mapping' from sysibm.sysdummy1;

select 'Catalog name = ' || ctg_name || '; Item Primary key = ' || itm_primary_key ||
'; Category path = ' || cfp_full_path as Item_category_mapping
from icm o
inner join itm on icm_item_id = itm_id
inner join ctg on icm_catalog_id = ctg_id
left outer join cfp on icm_category_id = cfp_category_id
where icm_next_version_id = 999999999
and icm_item_id in (
select icmitem from (
select icm_item_id icmitem, icm_next_version_id nxt, icm_cat_tree_id ctr, icm_category_id cat, icm_company_id cmp from icm
group by icm_item_id, icm_next_version_id, icm_cat_tree_id, icm_category_id, icm_company_id
having count(1) > 1) as t );

select  'Checking Collaboration Info' from sysibm.sysdummy1;

select 'Collaboration area name = ' || coa_name || '; Workflow name = ' || wfd_name ||
'; Workflow step name = ' || spt_leaf_step_text_path || '; Item primary key = ' || itm_primary_key
as Workflow_item_info
from wfe
left outer join coa on wfe_collaboration_area_id = coa_id
left outer join spt on wfe_source_step_at_path_id = spt_id
left outer join wfd on coa_wfl_id = wfd_id
left outer join wee on wfe_id = wee_event_id
left outer join cem on wee_entry_id = cem_ca_entry_id and cem_ca_id = coa_id
left outer join itm on cem_src_entry_id = itm_id
where wfe_event_status in ('NEW','PROCESSING')
and wfe_id in 
(select wfe_id id from wfe
group by wfe_id
having count(1) > 1);

select  'Completed' from sysibm.sysdummy1;
" > ${DB_SCRIPTS}/temp_verify.sql

#. ${DB_DIR}/util/run_db_cmd.sh --file=${DB_SCRIPTS}/temp_verify.sql --disconnect=no > $TOP/logs/constraint_violation_report.out 

db2 -t $CONNECTION
db2 -txf ${DB_SCRIPTS}/temp_verify.sql > $TOP/logs/constraint_violation_report.out 

else  
      ${ECHO} "Error! Database Environment has not been set."  
      exit 
fi

${ECHO} "CHECK " $TOP/logs/constraint_violation_report.out

END_TIME=`date` 

